<?php

/**
 * Administrative tools form.
 */
function starter_admin_tools_form($form, &$form_state) {
  drupal_set_title(st('Configure administrative tools'));
  $images_dir = base_path() . 'profiles/starter/images';
  $form['#attributes']['id'] = 'starter-form';

  //-- Admin menu module.
  $form['admin_menu_wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Administrative menu'),
    '#attributes' => array('class' => array('starter-highlighted')),
  );
  $form['admin_menu_wrapper']['admin_menu'] = array(
    '#type' => 'radio',
    '#title' => t('Enable'),
    '#suffix' => t('Provides a dropdown menu to most administrative tasks and other common destinations (to users with the proper permissions).'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['admin_menu_wrapper']['admin_menu_screenshot'] = array(
    '#type' => 'fieldset',
    '#title' => t('Screenshot'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#value' => '<img src="' . STARTER_IMAGE_PATH . '/admin_menu-screenshot.png" alt="admin menu screenshot"/>',
  );
  $form['admin_menu_wrapper']['admin_menu_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['admin_menu_wrapper']['admin_menu_settings']['admin_menu_toolbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Toolbar style.'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['admin_menu_wrapper']['admin_menu_settings']['admin_menu_position_fixed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Keep menu at top of page'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['admin_menu_wrapper']['admin_menu_settings']['admin_menu_tweak_modules'] = array(
    '#type' => 'checkbox',
    '#title' => t('Collapse module groups on the Modules page'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['admin_menu_wrapper']['admin_menu_settings']['admin_menu_margin_top'] = array(
    '#type' => 'checkbox',
    '#title' => t('Adjust top margin'),
    '#attributes' => array('checked' => 'checked'),
  );

  //-- Admin module.
  $form['admin_wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Admin'),
  );
  $form['admin_wrapper']['admin'] = array(
    '#type' => 'radio',
    '#title' => t('Enable'),
    '#suffix' => t('UI helpers for Drupal admins and managers.'),
  );
  $form['admin_wrapper']['admin_screenshot'] = array(
    '#type' => 'fieldset',
    '#title' => t('Screenshot'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#value' => '<img src="' . STARTER_IMAGE_PATH . '/admin-screenshot.png" alt="admin screenshot"/>',
  );
   $form['admin_wrapper']['admin_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
$form['admin_wrapper']['admin_settings']['layout'] = array(
    '#type' => 'select',
    '#title' => t('Layout'),
    '#description' => t('Choose a layout for the admin toolbar. Vertical works well with large, wide screens. Horizontal works well on screens with limited real estate.'),
    '#options' => array(
      'horizontal' => t('Horizontal'),
      'vertical' => t('Vertical'),
    ),
  );
  $form['admin_wrapper']['admin_settings']['position'] = array(
    '#type' => 'select',
    '#title' => t('Position'),
    '#description' => t('Choose a position for the admin toolbar that will not collide with other elements in your current theme.'),
    '#options' => array(
      'ne' => t('Top right'),
      'nw' => t('Top left'),
      'se' => t('Bottom right'),
      'sw' => t('Bottom left'),
    ),
  );
  $form['admin_wrapper']['admin_settings']['behavior'] = array(
    '#type' => 'select',
    '#title' => t('State on new pages'),
    '#description' => t('Choose toolbar behavior on new page loads.'),
    '#options' => array(
      'df' => t('Remember from previous page'),
      'ah' => t('Collapsed'),
    ),
  );

  //-- Core admin modules.
  $form['core_admin_wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Core admin tools'),
  );
  $form['core_admin_wrapper']['core_admin'] = array(
    '#type' => 'radio',
    '#title' => t('Enable'),
    '#suffix' => t('Drupal provides own admin tools.'),
  );
  $form['core_admin_wrapper']['core_admin_screenshot'] = array(
    '#type' => 'fieldset',
    '#title' => t('Screenshot'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#value' => '<img src="' . STARTER_IMAGE_PATH . '/core_admin-screenshot.png" alt="admin screenshot"/>',
  );
  $form['core_admin_wrapper']['core_admin_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['core_admin_wrapper']['core_admin_settings']['contextual'] = array(
    '#type' => 'checkbox',
    '#title' => t('Contextual links.'),
  );
  $form['core_admin_wrapper']['core_admin_settings']['overlay'] = array(
    '#type' => 'checkbox',
    '#title' => t('Overlay'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['core_admin_wrapper']['core_admin_settings']['shortcut'] = array(
    '#type' => 'checkbox',
    '#title' => t('Shortcut'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['core_admin_wrapper']['core_admin_settings']['toolbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Toolbar'),
    '#attributes' => array('checked' => 'checked'),
  );
  $form['core_admin_wrapper']['core_admin_settings']['dashboard'] = array(
    '#type' => 'checkbox',
    '#title' => t('Dashboard'),
  );

  //-- No admin tools.
  $form['no'] = array(
    '#type' => 'radio',
    '#title' => t('Thanks. I don\'t want use any administrative tools.'),
  );
  $form['sbmt'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}
  
/**
 * Add administrative modules to modules list.
 */
function starter_admin_tools_form_submit($form, &$form_state) {
  $values = &$form_state['values'];
  $modules = variable_get('install_profile_modules', array());
  $config = variable_get('starter_config', array('variables' => array()));

  //-- Administartor menu module.
  if ($values['admin_menu']) {
    $modules[] = 'admin_menu';
    if ($values['admin_menu_toolbar']) {
      $modules[] = 'admin_menu_toolbar';
    }
    foreach (array(
      'admin_menu_position_fixed',
      'admin_menu_tweak_modules',
      'admin_menu_margin_top',
    ) as $variable) {
      $config['variables'][$variable] = (int)!empty($values[$variable]);
    }
  }

  //-- Admin module.
  elseif ($values['admin']) {
    $modules[] = 'admin';
    foreach (array(
      'layout' => $values['layout'],
      'position' => $values['position'],
      'behavior' => $values['behavior'],
    ) as $key => $value) {
      $config['variables']['admin_toolbar'][$key] = $value;
    }
  }

  //-- Core admin modules.
  elseif ($values['core_admin']) {
    foreach (array(
      'contextual',
      'overlay',
      'shortcut',
      'toolbar',
      'dashboard',
    ) as $module) {
      if ($values[$module]) {
        $modules[] = $module;
      }
    }
  }

  variable_set('install_profile_modules', $modules);
  variable_set('starter_config', $config);
}
