<?php

/**
 * Installation step callback.
 * 
 * @param $install_state
 *   An array of information about the current installation state.
 */
function starter_final_site_setup($install_state) {

  $config = variable_get('starter_config', array('variables' => array()));
  $modules = variable_get('install_profile_modules', array());

  //-- Set variables from starter settings forms.
  foreach ($config['variables'] as $key => $value) {
    variable_set($key, $value);
  }
 
  //-- File system.
  // variable_set('file_public_path', 'files');
  // variable_set('file_temporary_path',  'files/tmp');

  //-- Admin theme.
  db_update('system')
    ->fields(array('status' => 1))
    ->condition('type', 'theme')
    ->condition('name', 'seven')
    ->execute();
  variable_set('admin_theme', 'seven');
  variable_set('node_admin_theme', '1');
  
  //-- Text formats.
  $filtered_html_format = array(
    'format' => 'filtered_html',
    'name' => t('Filtered HTML'),
    'weight' => 0,
    'filters' => array(
      // URL filter.
      'filter_url' => array(
        'weight' => 0,
        'status' => 1,
      ),
      // HTML filter.
      'filter_html' => array(
        'weight' => 1,
        'status' => 1,
      ),
      // Line break filter.
      'filter_autop' => array(
        'weight' => 2,
        'status' => 1,
      ),
      // HTML corrector filter.
      'filter_htmlcorrector' => array(
        'weight' => 10,
        'status' => 1,
      ),
    ),
  );
  $filtered_html_format = (object) $filtered_html_format;
  filter_format_save($filtered_html_format);

  $full_html_format = array(
    'format' => 'full_html',
    'name' => t('Full HTML'),
    'weight' => 1,
    'filters' => array(
      // URL filter.
      'filter_url' => array(
        'weight' => 0,
        'status' => 1,
      ),
      // Line break filter.
      'filter_autop' => array(
        'weight' => 1,
        'status' => 1,
      ),
      // HTML corrector filter.
      'filter_htmlcorrector' => array(
        'weight' => 10,
        'status' => 1,
      ),
    ),
  );
  $full_html_format = (object) $full_html_format;
  filter_format_save($full_html_format);

  //-- Allow visitor account creation with administrative approval.
  variable_set('user_register', USER_REGISTER_VISITORS_ADMINISTRATIVE_APPROVAL);

  //-- Insert default pre-defined node types into the database.
  $content_types = array();
  if (!empty($config['content_types']['page'])) {
    $content_types[] = array(
      'type' => 'page',
      'name' => t('Basic page'),
      'base' => 'node_content',
      'description' => t("Use <em>basic pages</em> for your static content, such as an 'About us' page."),
      'custom' => 1,
      'modified' => 1,
      'locked' => 0,
      'title_label' => t('Title')
    );
    // Default "Basic page" to not be promoted and have comments disabled.
    variable_set('node_options_page', array('status'));
    // Don't display date and author information for "Basic page" nodes by default.
    variable_set('node_submitted_page', FALSE);
  }
  if (!empty($config['content_types']['article'])) {
    $content_types[] = array(
      'type' => 'article',
      'name' => t('Article'),
      'base' => 'node_content',
      'description' => t('Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.'),
      'custom' => 1,
      'modified' => 1,
      'locked' => 0,
      'title_label' => t('Title')
    );
  }
  foreach ($content_types as $content_type) {
    $content_type = node_type_set_defaults($content_type);
    node_type_save($content_type);
    node_add_body_field($content_type);
  }
  
  // Add about page.
  if (!empty($config['content_types']['page'])) {
    $node = new stdClass();
    $node->type = 'page';
    node_object_prepare($node);
    $node->title    = t('About');
    $node->language = LANGUAGE_NONE;
    if (module_exists('comment')) {
      $node->comment = COMMENT_NODE_HIDDEN;
    }
    $node->body[$node->language][0]['value']   = t('Place here information about your company.');
    $node->body[$node->language][0]['format']  = 'filtered_html';
    $node->path = array('alias' => 'about');
    node_save($node);
    $item = array(
      'link_title' => t('About'),
      'link_path' => 'node/' . $node->nid,
      'menu_name' => 'main-menu',
      'weight' => 20,
    );
    menu_link_save($item);
  }

  //-- Enable filter_html permissions for system roles.
  $filtered_html_permission = filter_permission_name($filtered_html_format);
  user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, array($filtered_html_permission));
  user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, array($filtered_html_permission));

  //-- Enable content permissions for system roles.
  user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, array('access content'));
  user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, array('access content'));
  
  //-- Create a default role for site administrators, with all available permissions assigned.
  $admin_role = new stdClass();
  $admin_role->name = 'administrator';
  $admin_role->weight = 2;
  user_role_save($admin_role);
  user_role_grant_permissions($admin_role->rid, array_keys(module_invoke_all('permission')));
  // Set this as the administrator role.
  variable_set('user_admin_role', $admin_role->rid);
  // Assign user 1 the "administrator" role.
  db_insert('users_roles')
    ->fields(array('uid' => 1, 'rid' => $admin_role->rid))
    ->execute();

  //-- Create a Home link in the main menu.
  $item = array(
    'link_title' => st('Home'),
    'link_path' => '<front>',
    'menu_name' => 'main-menu',
  );
  menu_link_save($item);

  //-- Module specific setup.
  foreach(module_list() as $module) {
    if (function_exists($function = 'starter_' . $module . '_setup')) {
      $function();
    }
  }

  //-- Change default date formats.
  system_date_format_save(array(
    'format' => 'd.m.Y - H:i',
    'type' => 'custom',
    'locked' => 0,
    'is_new' => 1,
  ));
  variable_set('date_format_long', 'l, j F, Y - H:i');
  variable_set('date_format_medium', 'j F, Y - H:i');
  variable_set('date_format_short', 'd.m.Y - H:i');


  //-- Enable some standard blocks.
  $default_theme = variable_get('theme_default', 'bartik');
  $admin_theme = 'seven';
  $blocks = array(
    array(
      'module' => 'system',
      'delta' => 'main',
      'theme' => $default_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'content',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'node',
      'delta' => 'recent',
      'theme' => $admin_theme,
      'status' => 1,
      'weight' => 10,
      'region' => 'dashboard_main',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'user',
      'delta' => 'login',
      'theme' => $default_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'sidebar_first',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'system',
      'delta' => 'navigation',
      'theme' => $default_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'sidebar_first',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'system',
      'delta' => 'powered-by',
      'theme' => $default_theme,
      'status' => 1,
      'weight' => 10,
      'region' => 'footer',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'system',
      'delta' => 'help',
      'theme' => $default_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'help',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'system',
      'delta' => 'main',
      'theme' => $admin_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'content',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'system',
      'delta' => 'help',
      'theme' => $admin_theme,
      'status' => 1,
      'weight' => 0,
      'region' => 'help',
      'pages' => '',
      'cache' => -1,
    ),
    array(
      'module' => 'user',
      'delta' => 'login',
      'theme' => $admin_theme,
      'status' => 1,
      'weight' => 10,
      'region' => 'content',
      'pages' => '',
      'cache' => -1,
    ),
  );
 
  foreach ($blocks as $block) {
    db_update('block')
      ->fields($block)
      ->condition('module', $block['module'])
      ->condition('delta', $block['delta'])
      ->condition('theme', $block['theme'])
      ->execute();
  }

  //-- Change default logo
  $theme_settings = array(
    'toggle_logo' => 1, 
    'toggle_name' => 1, 
    'toggle_slogan' => 1, 
    'toggle_node_user_picture' => 1, 
    'toggle_comment_user_picture' => 1, 
    'toggle_comment_user_verification' => 1, 
    'toggle_favicon' => 1, 
    'toggle_main_menu' => 1, 
    'toggle_secondary_menu' => 1,
    'default_logo' => 0,
    'logo_path' => file_unmanaged_copy(STARTER_PROFILE_PATH . '/images/logo.png'),
    'logo_upload' => '',
    'default_favicon' => 1,
    'favicon_path' => '',
    'favicon_upload' => '',      
  );
  variable_set('theme_bartik_settings', $theme_settings);
  
  //-- Update the menu router information.
  menu_rebuild();
 }
 