<?php

/**
 * Bueditor setup callback.
 */
function starter_bueditor_setup() {
  $file = STARTER_PROFILE_PATH . '/includes/starter_bueditor.inc';
  module_load_include('inc', 'bueditor', 'admin/bueditor.admin');
  if ($code = file_get_contents($file)) {
    if ($editor = bueditor_exec_editor_code($code)) {
      bueditor_save_import($editor);
    }
  }
  $eid = db_query('SELECT eid FROM {bueditor_editors} WHERE name=\'Starter\' LIMIT 1')->fetchField();
  if ($eid) {
    variable_set('bueditor_user1', $eid);
  }
}

/**
 * Dblog setup callback.
 */
function starter_dblog_setup() {
  if (module_exists('dblog')) {
    db_delete('watchdog')
      ->condition('severity', WATCHDOG_NOTICE, '>=')
      ->execute();
  }
}

/**
 * Contact setup callback.
 */
function starter_contact_setup() {
  $item = array(
    'link_title' => t('Contact'),
    'link_path' => 'contact',
    'menu_name' => 'main-menu',
    'weight' => 10,
  );
  menu_link_save($item);
}

/**
 * Forum setup callback.
 */
function starter_forum_setup() {
  $item = array(
    'link_title' => t('Forum'),
    'link_path' => 'forum',
    'menu_name' => 'main-menu',
    'weight' => 1,
  );
  menu_link_save($item);
  
  // Delete all terms from forum vocabulary.
  $forum_vid = variable_get('forum_nav_vocabulary');
  foreach (taxonomy_get_tree($forum_vid) as $term) {
    taxonomy_term_delete($term->tid);
  }

  // Create a default forums.
  $edit = array(
    'name' => t('General'),
    'parent' => array(0),
    'vid' => $forum_vid,
  );
  $container = (object) $edit;
  taxonomy_term_save($container);

  foreach(array('News and announcements', 'General discussion', 'Events') as $term_name) {
    $edit = array(
      'name' => t($term_name),
      'parent' => array($container->tid),
      'vid' => $forum_vid,
    );
    $term = (object) $edit;
    taxonomy_term_save($term);
  }

}

/**
 * Taxonomy setup callback.
 */
function starter_taxonomy_setup() {
  // Create a default vocabulary named "Метки", enabled for the 'article' content type.
  $description = st('Use tags to group articles on similar topics into categories.');
  $help = st('Enter a comma-separated list of words to describe your content.');
  $vocabulary = (object) array(
    'name' => st('Tags'),
    'description' => $description,
    'machine_name' => 'tags',
    'help' => $help,
  );
  taxonomy_vocabulary_save($vocabulary);
  
  if (array_key_exists('article', node_type_get_types())) {

    $field = array(
      'field_name' => 'field_' . $vocabulary->machine_name,
      'type' => 'taxonomy_term_reference',
      // Set cardinality to unlimited for tagging.
      'cardinality' => FIELD_CARDINALITY_UNLIMITED,
      'settings' => array(
        'allowed_values' => array(
          array(
            'vocabulary' => $vocabulary->machine_name,
            'parent' => 0,
          ),
        ),
      ),
    );
    field_create_field($field);

    $instance = array(
      'field_name' => 'field_' . $vocabulary->machine_name,
      'entity_type' => 'node',
      'label' => $vocabulary->name,
      'bundle' => 'article',
      'description' => $vocabulary->help,
      'widget' => array(
        'type' => 'taxonomy_autocomplete',
        'weight' => -4,
      ),
      'display' => array(
        'default' => array(
          'type' => 'taxonomy_term_reference_link',
          'weight' => -1,
        ),
        'teaser' => array(
          'type' => 'taxonomy_term_reference_link',
          'weight' => -1,
        ),
      ),
    );
    field_create_instance($instance);
  }

}

/**
 * Image setup callback.
 */
function starter_image_setup() {
   // Enable user picture support and set the default to a square thumbnail option.
  variable_set('user_pictures', '1');
  variable_set('user_picture_dimensions', '1024x1024');
  variable_set('user_picture_file_size', '800');
  variable_set('user_picture_style', 'thumbnail');

  if (!array_key_exists('article', node_type_get_types()) || module_exists('media')) {
    return;
  }
  
  // Create an image field named "Image", enabled for the 'article' content type.
  // Many of the following values will be defaulted, they're included here as an illustrative examples.
  // See http://api.drupal.org/api/function/field_create_field/7
  $field = array(
    'field_name' => 'field_image',
    'type' => 'image',
    'cardinality' => 1,
    'translatable' => TRUE,
    'locked' => FALSE,
    'indexes' => array('fid' => array('fid')),
    'settings' => array(
      'uri_scheme' => 'public',
      'default_image' => FALSE,
    ),
    'storage' => array(
      'type' => 'field_sql_storage',
      'settings' => array(),
    ),
  );
  field_create_field($field);

  // Many of the following values will be defaulted, they're included here as an illustrative examples.
  // See http://api.drupal.org/api/function/field_create_instance/7
  $instance = array(
    'field_name' => 'field_image',
    'entity_type' => 'node',
    'label' => st('Image'),
    'bundle' => 'article',
    'description' => st('Upload an image to go with this article.'),
    'required' => FALSE,

    'settings' => array(
      'file_directory' => 'field/image',
      'file_extensions' => 'png gif jpg jpeg',
      'max_filesize' => '',
      'max_resolution' => '',
      'min_resolution' => '',
      'alt_field' => TRUE,
      'title_field' => '',
    ),
    'widget' => array(
      'type' => 'image_image',
      'settings' => array(
        'progress_indicator' => 'throbber',
        'preview_image_style' => 'thumbnail',
      ),
      'weight' => -1,
    ),
    'display' => array(
      'default' => array(
        'label' => st('hidden'),
        'type' => 'image',
        'settings' => array('image_style' => 'large', 'image_link' => ''),
        'weight' => -1,
      ),
      'teaser' => array(
        'label' => st('hidden'),
        'type' => 'image',
        'settings' => array('image_style' => 'medium', 'image_link' => 'content'),
        'weight' => -1,
      ),
    ),
  );

  // Add insert button.
  if (module_exists('insert')) {
    $instance['widget']['settings'] += array(
      'insert' => 1,
      'insert_styles' => array('auto' => 'auto'),
      'insert_default' => 'auto',
      'insert_class' => '',
      'insert_width' => '',
    );
  }

  field_create_instance($instance);
}


/**
 * Media setup callback.
 */
function starter_media_setup() {

  if (!array_key_exists('article', node_type_get_types())) {
    return;
  }
  // Create a media field named "Media", enabled for the 'article' content type.
  // Many of the following values will be defaulted, they're included here as an illustrative examples.
  // See http://api.drupal.org/api/function/field_create_field/7
  $field = array(
    'field_name' => 'field_media',
    'type' => 'media',
    'cardinality' => -1,
    'translatable' => FALSE,
    'locked' => FALSE,
    'indexes' => array('fid' => array('fid')),
    'settings' => array(
    ),
    'storage' => array(
      'type' => 'field_sql_storage',
      'settings' => array(),
    ),
  );
  field_create_field($field);

  // Many of the following values will be defaulted, they're included here as an illustrative examples.
  // See http://api.drupal.org/api/function/field_create_instance/7
  $instance = array(
    'field_name' => 'field_media',
    'entity_type' => 'node',
    'label' => st('Media'),
    'bundle' => 'article',
    'description' => st('Upload an image to go with this article.'),
    'required' => FALSE,
    'settings' => array(
      'file_directory' => 'field/image',
      'file_extensions' => 'jpg jpeg gif png txt doc xls pdf ppt pps odt ods odp mp3 mov m4v mp4 mpeg avi ogg wmv ico',
    ),
    'widget' => array(
      'type' => 'media_generic',
      'settings' => array(
      ),
      'weight' => -1,
    ),
    'display' => array(
      'default' => array(
        'label' => st('hidden'),
        'type' => 'media_large',
        'settings' => array(),
        'weight' => -1,
      ),
    ),
  );
  field_create_instance($instance);
}

/**
 * Ckeditor setup callback.
 */
function starter_ckeditor_setup() {

}

/**
 * Comment setup callback.
 */
function starter_comment_setup() {
  if (array_key_exists('page', node_type_get_types())) {
    variable_set('comment_page', COMMENT_NODE_HIDDEN);    
  }
  //-- Enable coment permissions for system roles.
  user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, array('access comments'));
  user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, array('access comments', 'post comments', 'skip comment approval'));
}

/**
 * Ckeditor setup callback.
 */
function starter_imce_setup() {
  if (module_exists('ckeditor')) {
    foreach (array('Advanced', 'Full') as $cke_profile_name) {
      $cke_profile = ckeditor_profile_load($cke_profile_name);
      $cke_profile->settings['filebrowser'] = 'imce';
      db_update('ckeditor_settings')
        ->fields(array('settings' => serialize($cke_profile->settings)))
        ->condition('name', $cke_profile_name)
        ->execute();
    }
  }
}

/**
 * Taxonomy container setup callback.
 */
function starter_taxonomy_container_setup() {
  $instance = field_read_instance('node', 'taxonomy_forums', 'forum');
  $instance['widget']['type'] = 'taxonomy_container';
  field_update_instance($instance);
}
