<?php

// Install profiles cannot use drupal_get_path().
// See http://drupal.org/node/241086
define('STARTER_PROFILE_PATH', 'profiles/starter');
define('STARTER_IMAGE_PATH', STARTER_PROFILE_PATH . '/images');

if (isset($install_state['parameters']['locale'])) {
  define('STARTER_LOCALE', $install_state['parameters']['locale']);
}

// Change maintence theme.
if (!empty($install_state['interactive'])) {
  $themes = list_themes();
  _drupal_theme_initialize($themes['starter_maintence'], array($themes['seven']), '_theme_load_offline_registry');
}

/**
 * Implements hook_init().
 */
function starter_init() {
  // We don't need include this file after an installation process.
  // See http://drupal.org/node/1242956.
  if (variable_get('install_task', '') == 'done') {
    db_update('system')
      ->fields(array('name' => 'minimal', 'filename' => 'profiles/minimal/minimal.profile'))
      ->condition('type', 'module')
      ->condition('name', 'starter')
      ->execute();
    variable_set('install_profile', 'minimal');
    cache_clear_all('system_list', 'cache_bootstrap');
    variable_del('starter_config');
  }
  else {
    drupal_add_js(STARTER_PROFILE_PATH . '/includes/starter.js');
    // Include all files.
    require 'includes/starter_text_editor.inc';
    require 'includes/starter_admin_tools.inc';
    require 'includes/starter_file_handling.inc';
    require 'includes/starter_content_types.inc';
    require 'includes/starter_final_site_setup.inc';
    require 'includes/starter_modules_setup.inc';
  }
}

/**
 * Set starter as default install profile.
 *
 * Must use system as the hook module because starter is not active yet.
 */
function system_form_install_select_profile_form_alter(&$form, $form_state) {
  foreach($form['profile'] as $key => $element) {
    $form['profile'][$key]['#value'] = 'starter';
  }
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function starter_form_install_configure_form_alter(&$form, $form_state) {
  $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
  $form['site_information']['site_mail']['#default_value'] = 'no-reply@' . $_SERVER['SERVER_NAME'];
  $form['admin_account']['account']['name']['#default_value'] = 'admin';
  $form['admin_account']['account']['mail']['#default_value'] = 'admin@' .  $_SERVER['SERVER_NAME'];
  $form['update_notifications']['update_status_module']['#default_value'] = array(0, 0);
  
  
  foreach (_locale_get_predefined_list() as $langcode => $language) {
    $languages[$langcode] = new stdClass;
    $languages[$langcode]->language = $langcode;
  }
  if ($best_match_langcode = locale_language_from_browser($languages)) {
    $form['server_settings']['site_default_country']['#default_value'] = strtoupper($best_match_langcode);
  }
}

/**
 * Implements hook_install_tasks().
 */
function starter_install_tasks($install_state) {
  return array(
    'starter_text_editor_form' => array(
      'display_name' => st('Configure text editor'), 
      'type' => 'form',
    ),
    'starter_admin_tools_form' => array(
      'display_name' => st('Configure administrative tools'), 
      'type' => 'form',
    ),
    'starter_file_handling_form' => array(
      'display_name' => st('Configure file handling'), 
      'type' => 'form',
    ),
    'starter_content_types_form' => array(
      'display_name' => st('Configure content types'), 
      'type' => 'form',
    ),
    'starter_profile_modules' => array(
      'display_name' => st('Install contributed modules'), 
      'type' => 'batch',
      'function' => 'install_profile_modules',
    ),
    'starter_final_site_setup' => array(
     'display_name' => st('Final setup'),
     'display' => FALSE,
    ),
  );
}

/**
 * Implements hook_install_tasks() alter.
 */
function starter_install_tasks_alter(&$tasks, $install_state) {
  $tasks['install_profile_modules']['display_name'] = t('Prepare installation profile');
}
